TargetTextHighlight class

Constructors

TargetTextHighlight({required String targetText, int? priority, TextStyle? style, void onTap(TextRange range)?, bool caseSensitive = false, bool highlightInUrl = false})
const

Properties

caseSensitive bool
if case sensitive is true
final
hashCode int
The hash code for this object.
no setterinherited
highlightInUrl bool
If the pattern is found with-in a URL, below boolean let user set if the pattern in the URL should be highlighted or not
final
onTap → void Function(TextRange range)?
Callback function to be called when the highlight text is clicked
final
priority int?
Which targetText style should be given priority. If there are two targets with same substring, then the higher lower priority target style will be overridden by the higher priority target style.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle?
User defined text style for the specific target
final
targetText String
The regex pattern to match the target text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited