TextHighlight class

Constructors

TextHighlight({required TargetTextHighlight targetHighlight, Set<TextRange> highlightRanges = const <TextRange>{}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
highlightRanges Set<TextRange>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetHighlight TargetTextHighlight
final

Methods

copyWith({TargetTextHighlight? targetHighlight, Set<TextRange>? highlightRanges}) TextHighlight
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited