urlRegex property

String urlRegex
final

Url pattern in string form which would be detected by the package, like r'is'.

The default pattern is meant to detect the urls which starts with https:// or https:// or ftp://.

The default also detects the urls which don't start with https or http like example.com or example.net. So in summary the deafult behavior detects urls like:

  • example.com,
  • https://example.com,
  • https://www.example.com/path?query=1#fragment.

Implementation

final String urlRegex;