TargetTextHighlights class
Constructors
-
TargetTextHighlights({List<
TargetTextHighlight> targetHighlights = const <TargetTextHighlight>[], TextStyle? defaultHighlightStyle})
Properties
- defaultHighlightStyle → TextStyle?
-
Default text style to be applied when multiple highlights share the same
style. Instead of passing the same style redundantly for
individual highlights, you can specify it here as a fallback.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetHighlights
→ List<
TargetTextHighlight> -
final
Methods
-
getPriorityTargetTextHighlight(
) → TargetTextHighlight? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited