defaultHighlightStyle property
Default text style to be applied when multiple highlights share the same style. Instead of passing the same style redundantly for individual highlights, you can specify it here as a fallback.
Implementation
final TextStyle? defaultHighlightStyle;